summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authordrbrain <drbrain@b2dd03c8-39d4-4d8f-98ff-823fe69b080e>2007-12-28 06:39:15 +0000
committerdrbrain <drbrain@b2dd03c8-39d4-4d8f-98ff-823fe69b080e>2007-12-28 06:39:15 +0000
commitecb7eb6ba4a6f10ac9ff2e7531c9b12ac81646c5 (patch)
tree798ee6dd17a811a2819ca4be117e899245f5e094
parentcc54d01f8bcbffb2a66db767bbe3f367b86a78c5 (diff)
Move RDoc markup samples to sample/rdoc/markup directory
git-svn-id: svn+ssh://ci.ruby-lang.org/ruby/trunk@14761 b2dd03c8-39d4-4d8f-98ff-823fe69b080e
-rw-r--r--ChangeLog4
-rw-r--r--sample/rdoc/markup/rdoc2latex.rb (renamed from lib/rdoc/markup/sample/rdoc2latex.rb)0
-rw-r--r--sample/rdoc/markup/sample.rb (renamed from lib/rdoc/markup/sample/sample.rb)10
3 files changed, 8 insertions, 6 deletions
diff --git a/ChangeLog b/ChangeLog
index e852ee6a99..e9bd002348 100644
--- a/ChangeLog
+++ b/ChangeLog
@@ -1,3 +1,7 @@
+Fri Dec 28 15:38:29 2007 Eric Hodel <drbrain@segment7.net>
+
+ * lib/rdoc/markup/sample/: Move to sample/rdoc/markup directory.
+
Fri Dec 28 15:15:12 2007 Akinori MUSHA <knu@iDaemons.org>
* lib/irb/completion.rb: Remove garbage ("X=1").
diff --git a/lib/rdoc/markup/sample/rdoc2latex.rb b/sample/rdoc/markup/rdoc2latex.rb
index 26563b75da..26563b75da 100644
--- a/lib/rdoc/markup/sample/rdoc2latex.rb
+++ b/sample/rdoc/markup/rdoc2latex.rb
diff --git a/lib/rdoc/markup/sample/sample.rb b/sample/rdoc/markup/sample.rb
index a375b54564..db5d88d150 100644
--- a/lib/rdoc/markup/sample/sample.rb
+++ b/sample/rdoc/markup/sample.rb
@@ -1,21 +1,19 @@
# This program illustrates the basic use of the SimpleMarkup
-# class. It extracts the first comment block from the
+# class. It extracts the first comment block from the
# simple_markup.rb file and converts it into HTML on
# standard output. Run it using
#
# % ruby sample.rb
#
# You should be in the sample/ directory when you do this,
# as it hardwires the path to the files it needs to require.
-# This isn't necessary in the code you write once you've
+# This isn't necessary in the code you write once you've
# installed the package.
#
# For a better way of formatting code comment blocks (and more)
# see the rdoc package.
#
-$:.unshift "../../.."
-
require 'rdoc/markup/simple_markup'
require 'rdoc/markup/simple_markup/to_html'
@@ -23,7 +21,7 @@ require 'rdoc/markup/simple_markup/to_html'
input_string = ""
-File.foreach("../simple_markup.rb") do |line|
+File.foreach("../../../lib/rdoc/markup/simple_markup.rb") do |line|
break unless line.gsub!(/^\# ?/, '')
input_string << line
end
@@ -1,21 +1,19 @@
# % ruby sample.rb
#
-# You should be in the sample/ directory when you do this,
+# You should be in the sample/rdoc/markup/ directory when you do this,
# as it hardwires the path to the files it needs to require.